@@ -34,15 +34,15 @@ public:
         QWidget *value;
     };
 
-    FileMetaDataWidgetPrivate(FileMetaDataWidget *parent);
+    explicit FileMetaDataWidgetPrivate(FileMetaDataWidget *parent);
     ~FileMetaDataWidgetPrivate();
 
+    FileMetaDataWidgetPrivate(const FileMetaDataWidgetPrivate&) = delete;
+    FileMetaDataWidget& operator=(const FileMetaDataWidgetPrivate&) = delete;
+
     void deleteRows();
 
     void slotLoadingFinished();
-    void slotLinkActivated(const QString &link);
-    void slotDataChangeStarted();
-    void slotDataChangeFinished();
 
     QStringList sortedKeys(const QVariantMap &data) const;
     QLabel *createLabel(const QString &key, const QString &itemLabel, FileMetaDataWidget *parent);
@@ -193,24 +193,6 @@ void FileMetaDataWidgetPrivate::slotLoadingFinished()
     Q_EMIT q->metaDataRequestFinished(m_provider->items());
 }
 
-void FileMetaDataWidgetPrivate::slotLinkActivated(const QString &link)
-{
-    const QUrl url = QUrl::fromUserInput(link);
-    if (url.isValid()) {
-        Q_EMIT q->urlActivated(url);
-    }
-}
-
-void FileMetaDataWidgetPrivate::slotDataChangeStarted()
-{
-    q->setEnabled(false);
-}
-
-void FileMetaDataWidgetPrivate::slotDataChangeFinished()
-{
-    q->setEnabled(true);
-}
-
 QStringList FileMetaDataWidgetPrivate::sortedKeys(const QVariantMap &data) const
 {
     // Create a map, where the translated label prefixed with the
